<?php
/**
 * Code Manas Theme Customizer
 *
 * @package Code_Manas
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function code_manas_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'code_manas_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'code_manas_customize_partial_blogdescription',
		) );
	}

	if ( ! class_exists( 'Kirki' ) ) {
		return;
	}
	// Get all default values
	$defaults = code_manas_get_theme_mods_defaults();
	
	// Move default sections
	$wp_customize->get_section( 'title_tagline' )->panel = 'code_manas_header';
	$wp_customize->get_section( 'colors' )->panel = 'code_manas_advance_options';
	$wp_customize->get_section( 'custom_css' )->panel = 'code_manas_advance_options';
	$wp_customize->get_section( 'background_image' )->panel = 'code_manas_advance_options';

	// Change priority of default sections
	$wp_customize->get_section( 'static_front_page' )->priority = 20;

	// Customize default behavior of Header Image
	$wp_customize->get_control( 'header_image' )->section = 'code_manas_featured_section';
	$wp_customize->get_control( 'header_image' )->priority = 100;
	$wp_customize->get_control( 'header_image' )->active_callback = function() {
		$defaults = code_manas_get_theme_mods_defaults();
		return ( 'image' === get_theme_mod('featured_bg') && get_theme_mod( 'featured_enable', 1 ) ) ;
	};
}
add_action( 'customize_register', 'code_manas_customize_register' );

/**
 * Add theme option fields from Kirki framework.
 */
add_action( 'init', function() {
	if ( ! class_exists( 'Kirki' ) ) {
		return;
	}

	// Get all default values
	$defaults = code_manas_get_theme_mods_defaults();

	// Add Kirki config for this theme
	Kirki::add_config( 'code_manas_config', array(
		'capability'    => 'edit_theme_options',
		'option_type'   => 'theme_mod',
	) );

	// Add header panel
	Kirki::add_panel( 'code_manas_header', array(
	    'priority'    => 10,
	    'title'       => esc_html__( 'Header', 'code-manas' ),
	    'description' => esc_html__( 'Manage header section.', 'code-manas' ),
	) );

	// Add header options section
	Kirki::add_section( 'code_manas_header_section', array(
	    'title'          => esc_html__( 'Header options', 'code-manas' ),
	    'panel'          => 'code_manas_header',
	    'priority'		 => 30
	) );

	// Add header alignment option
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'toggle',
		'settings'    => 'header_alignment',
		'label'       => esc_html__( 'Center align header:', 'code-manas' ),
		'description'       => esc_html__( 'Enabling it will align the header and secondary menu to center.', 'code-manas' ),
		'section'     => 'code_manas_header_section',
		'default'     => 0,
	) );

	// Add primary menu sticky option
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'toggle',
		'settings'    => 'primary_menu_sticky',
		'label'       => esc_html__( 'Make Primary menu sticky:', 'code-manas' ),
		'description'       => esc_html__( 'Enabling it will make the primary menu stick to the top.', 'code-manas' ),
		'section'     => 'code_manas_header_section',
		'default'     => 1,
	) );

	// Add featured section
	Kirki::add_section( 'code_manas_featured_section', array(
	    'title'          => esc_html__( 'Featured section', 'code-manas' ),
	    'description'    => esc_html__( 'Featured section is the top section which appears at top in everywhere as managed.', 'code-manas' ),
	    'panel'          => 'code_manas_header',
	    'priority'		 => 40
	) );

	// Add featured section enable/disable option.
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'switch',
		'settings'    => 'featured_enable',
		'label'       => esc_html__( 'Featured section', 'code-manas' ),
		'section'     => 'code_manas_featured_section',
		'default'     => 0,
		'choices'     => array(
			'on'  => esc_html__( 'Enable', 'code-manas' ),
			'off' => esc_html__( 'Disable', 'code-manas' ),
		),
	) );

	$featured_enable_active_cb = array(
		'setting'  => 'featured_enable',
		'operator' => '===',
		'value'    => true,
	);

	// Featured section entire site enable/disable option
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'radio',
		'settings'    => 'featured_enable_on',
		'label'       => esc_html__( 'Enable on', 'code-manas' ),
		'section'     => 'code_manas_featured_section',
		'default'     => $defaults['featured_enable_on'],
		'active_callback'    => array( $featured_enable_active_cb ),
		'choices'     => array(
			'homepage'   => array(
				esc_html__( 'Frontpage', 'code-manas' ),
				esc_html__( 'Will be enabled only on homepage.', 'code-manas' ),
			),
			'entire-site' => array(
				esc_html__( 'Entire site', 'code-manas' ),
				esc_html__( 'Will be enabled on the whole site.', 'code-manas' ),
			),
		),
	) );


	// Add featured title
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'text',
		'settings'    => 'featured_title',
		'label'       => esc_html__( 'Title', 'code-manas' ),
		'section'     => 'code_manas_featured_section',
		'transport'	  => 'postMessage',
		'default'     => $defaults['featured_title'],
		'active_callback'    => array( $featured_enable_active_cb ),
		'partial_refresh' => array(
			'featured_title' => array(
				'selector'        => '.featured-text-content h1',
				'render_callback' => function() {
					return get_theme_mod( 'featured_title' );
				},
			),
		),
	) );

	// Add featured content
	Kirki::add_field( 'code_manas_config', array(
		'type'     => 'textarea',
		'settings' => 'featured_content',
		'label'    => esc_html__( 'Content', 'code-manas' ),
		'description'  => esc_html__( 'HTML allowed', 'code-manas' ),
		'section'  => 'code_manas_featured_section',
		'default'     => $defaults['featured_content'],
		'active_callback'    => array( $featured_enable_active_cb ),
		'partial_refresh' => array(
			'featured_content' => array(
				'selector'        => '.featured-text-content h2.theme-tagline',
				'render_callback' => function() {
					return get_theme_mod( 'featured_content' );
				},
			),
		),
	) );

	// Add featured background type option
	Kirki::add_field( 'code_manas_config', array(
		'type'     => 'radio-buttonset',
		'settings' => 'featured_bg',
		'label'    => esc_html__( 'Background', 'code-manas' ),
		'section'  => 'code_manas_featured_section',
		'active_callback'    => array( $featured_enable_active_cb ),
		'default'     => $defaults['featured_bg'],
		'choices'     => array(
			'image' => esc_html__( 'Image', 'code-manas' ),
			'color' => esc_html__( 'Color', 'code-manas' ),
		),
	) );

	// Add featured background color
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'color',
		'settings'    => 'featured_bg_color',
		'label'       => esc_html__( 'Background color', 'code-manas' ),
		'section'     => 'code_manas_featured_section',
		'default'     => $defaults['featured_bg_color'],
		'active_callback'    => array(
	    	array(
	    		'setting'  => 'featured_bg',
	    		'operator' => '===',
	    		'value'    => 'color',
	    	),
	    	$featured_enable_active_cb
	    ),
	) );

	// Add advance options panel
	Kirki::add_panel( 'code_manas_advance_options', array(
	    'priority'    => 30,
	    'title'       => esc_html__( 'Advance options', 'code-manas' ),
	) );

	// Add layout section
	Kirki::add_section( 'code_manas_layout_option_section', array(
	    'title'          => esc_html__( 'Layout options', 'code-manas' ),
	    'description'    => esc_html__( 'Layout options for site.', 'code-manas' ),
	    'panel'          => 'code_manas_advance_options',
	) );

	// Add site layout option
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'radio-image',
		'settings'    => 'site_layout',
		'label'       => esc_html__( 'Page width', 'code-manas' ),
		'section'     => 'code_manas_layout_option_section',
		'default'     => 'boxed',
		'choices'     => array(
			'boxed'   => get_theme_file_uri( '/assets/img/bx.png' ),
			'wide' => get_theme_file_uri( '/assets/img/ns.png' ),
		),
	) );	

	// Add advance menu section
	Kirki::add_section( 'code_manas_menu_option_section', array(
	    'title'          => esc_html__( 'Menu options', 'code-manas' ),
	    'description'    => esc_html__( 'Advanced options for menus.', 'code-manas' ),
	    'panel'          => 'code_manas_advance_options',
	) );

	// Add search option for primary menu
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'toggle',
		'settings'    => 'primary_menu_search_enable',
		'label'       => esc_html__( 'Enable search on Primary menu.', 'code-manas' ),
		'section'     => 'code_manas_menu_option_section',
		'default'     => 1,
	) );

	// Add search option for primary menu
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'toggle',
		'settings'    => 'secondary_menu_search_enable',
		'label'       => esc_html__( 'Enable search on Secondary menu.', 'code-manas' ),
		'section'     => 'code_manas_menu_option_section',
		'default'     => 1,
	) );

	// Add advance blog options
	Kirki::add_section( 'code_manas_blog_option_section', array(
	    'title'          => esc_html__( 'Blog/Archive options', 'code-manas' ),
	    'description'    => esc_html__( 'Advanced options for blog/archive.', 'code-manas' ),
	    'panel'          => 'code_manas_advance_options',
	) );

	// Add date enable option
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'toggle',
		'settings'    => 'blog_date_enable',
		'label'       => esc_html__( 'Enable date:', 'code-manas' ),
		'section'     => 'code_manas_blog_option_section',
		'default'     => 1,
	) );

	// Add author enable option
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'toggle',
		'settings'    => 'blog_author_enable',
		'label'       => esc_html__( 'Enable author:', 'code-manas' ),
		'section'     => 'code_manas_blog_option_section',
		'default'     => 1,
	) );

	// Add tag enable option
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'toggle',
		'settings'    => 'blog_tag_enable',
		'label'       => esc_html__( 'Enable tag:', 'code-manas' ),
		'section'     => 'code_manas_blog_option_section',
		'default'     => 1,
	) );

	// Add category enable option
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'toggle',
		'settings'    => 'blog_cat_enable',
		'label'       => esc_html__( 'Enable cat:', 'code-manas' ),
		'section'     => 'code_manas_blog_option_section',
		'default'     => 1,
	) );

	// Add comment enable option
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'toggle',
		'settings'    => 'blog_comment_enable',
		'label'       => esc_html__( 'Enable comment:', 'code-manas' ),
		'section'     => 'code_manas_blog_option_section',
		'default'     => 1,
	) );

	// Add image enable option
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'toggle',
		'settings'    => 'blog_image_enable',
		'label'       => esc_html__( 'Enable image:', 'code-manas' ),
		'section'     => 'code_manas_blog_option_section',
		'default'     => 1,
	) );

	// Add blog content type option
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'radio-buttonset',
		'settings'    => 'blog_content',
		'label'       => esc_html__( 'Blog content:', 'code-manas' ),
		'section'     => 'code_manas_blog_option_section',
		'default'     => 'excerpt',
		'choices'     => array(
			'excerpt'   => esc_html__( 'Excerpt', 'code-manas' ),
			'full' => esc_html__( 'Full content', 'code-manas' ),
		),
	) );

	// Add blog excerpt more text
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'text',
		'settings'    => 'blog_excerpt_more',
		'label'       => esc_html__( 'Read more text:', 'code-manas' ),
		'section'     => 'code_manas_blog_option_section',
		'default'     => $defaults['blog_excerpt_more'],
	) );

	// Add blog pagination type option
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'radio-buttonset',
		'settings'    => 'blog_pagination',
		'label'       => esc_html__( 'Pagination:', 'code-manas' ),
		'section'     => 'code_manas_blog_option_section',
		'default'     => 'numeric',
		'choices'     => array(
			'numeric'   => esc_html__( 'Numeric', 'code-manas' ),
			'wording' => esc_html__( 'Older/Newer', 'code-manas' ),
		),
	) );

	// Add archive/blog sidebar layout option
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'radio-image',
		'settings'    => 'archive_layout',
		'label'       => esc_html__( 'Archive/blog sidebar', 'code-manas' ),
		'description'       => esc_html__( 'This changes the sidebar position on archive, search and blog post page.', 'code-manas' ),
		'section'     => 'code_manas_blog_option_section',
		'default'     => 'ns',
		'choices'     => array(
			'ls'   => get_theme_file_uri( '/assets/img/ls.png' ),
			'ns' => get_theme_file_uri( '/assets/img/ns.png' ),
			'rs'  => get_theme_file_uri( '/assets/img/rs.png' ),
		),
	) );

	// Add advance posts options
	Kirki::add_section( 'code_manas_post_option_section', array(
	    'title'          => esc_html__( 'Posts options', 'code-manas' ),
	    'description'    => esc_html__( 'Note: This option will effect all the single posts.', 'code-manas' ),
	    'panel'          => 'code_manas_advance_options',
	) );

	// Add date enable option
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'toggle',
		'settings'    => 'post_date_enable',
		'label'       => esc_html__( 'Enable date:', 'code-manas' ),
		'section'     => 'code_manas_post_option_section',
		'default'     => 1,
	) );

	// Add author enable option
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'toggle',
		'settings'    => 'post_author_enable',
		'label'       => esc_html__( 'Enable author:', 'code-manas' ),
		'section'     => 'code_manas_post_option_section',
		'default'     => 1,
	) );

	// Add tag enable option
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'toggle',
		'settings'    => 'post_tag_enable',
		'label'       => esc_html__( 'Enable tag:', 'code-manas' ),
		'section'     => 'code_manas_post_option_section',
		'default'     => 1,
	) );

	// Add category enable option
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'toggle',
		'settings'    => 'post_cat_enable',
		'label'       => esc_html__( 'Enable cat:', 'code-manas' ),
		'section'     => 'code_manas_post_option_section',
		'default'     => 1,
	) );

	// Add comment enable option
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'toggle',
		'settings'    => 'post_comment_enable',
		'label'       => esc_html__( 'Enable comment:', 'code-manas' ),
		'section'     => 'code_manas_post_option_section',
		'default'     => 1,
	) );

	// Add image enable option
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'toggle',
		'settings'    => 'post_image_enable',
		'label'       => esc_html__( 'Enable image:', 'code-manas' ),
		'section'     => 'code_manas_post_option_section',
		'default'     => 1,
	) );

	// Add post pagination type option
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'radio-buttonset',
		'settings'    => 'post_pagination',
		'label'       => esc_html__( 'Pagination:', 'code-manas' ),
		'section'     => 'code_manas_post_option_section',
		'default'     => 'enable',
		'choices'     => array(
			'enable'   => esc_html__( 'Enable', 'code-manas' ),
			'disable' => esc_html__( 'Disable', 'code-manas' ),
		),
	) );

	// Add single posts sidebar layout option
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'radio-image',
		'settings'    => 'posts_layout',
		'label'       => esc_html__( 'Posts sidebar', 'code-manas' ),
		'description'       => esc_html__( 'This changes the sidebar position on all single posts.', 'code-manas' ),
		'section'     => 'code_manas_post_option_section',
		'default'     => 'rs',
		'choices'     => array(
			'ls'   => get_theme_file_uri( '/assets/img/ls.png' ),
			'ns' => get_theme_file_uri( '/assets/img/ns.png' ),
			'rs'  => get_theme_file_uri( '/assets/img/rs.png' ),
		),
	) );

	// Add advance pages options
	Kirki::add_section( 'code_manas_page_option_section', array(
	    'title'          => esc_html__( 'Pages options', 'code-manas' ),
	    'description'    => esc_html__( 'Note: This option will effect all the single pages.', 'code-manas' ),
	    'panel'          => 'code_manas_advance_options',
	) );

	// Add image enable option
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'toggle',
		'settings'    => 'page_image_enable',
		'label'       => esc_html__( 'Enable image:', 'code-manas' ),
		'section'     => 'code_manas_page_option_section',
		'default'     => 1,
	) );

	// Add single pages sidebar layout option
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'radio-image',
		'settings'    => 'pages_layout',
		'label'       => esc_html__( 'Pages sidebar', 'code-manas' ),
		'description'       => esc_html__( 'This changes the sidebar position on all single pages.', 'code-manas' ),
		'section'     => 'code_manas_page_option_section',
		'default'     => 'rs',
		'choices'     => array(
			'ls'   => get_theme_file_uri( '/assets/img/ls.png' ),
			'ns' => get_theme_file_uri( '/assets/img/ns.png' ),
			'rs'  => get_theme_file_uri( '/assets/img/rs.png' ),
		),
	) );

	// Add footer section
	Kirki::add_section( 'code_manas_footer_section', array(
	    'title'          => esc_html__( 'Footer section', 'code-manas' ),
	    'priority'		 => 200
	) );

	// Add copyright content
	Kirki::add_field( 'code_manas_config', array(
		'type'     => 'textarea',
		'settings' => 'footer_copyright',
		'label'    => esc_html__( 'Footer content:', 'code-manas' ),
		'description'  => esc_html__( 'HTML allowed', 'code-manas' ),
		'section'  => 'code_manas_footer_section',
		'default'     => $defaults['footer_copyright'],
		'partial_refresh' => array(
			'footer_copyright' => array(
				'selector'        => 'footer#colophon .copyright',
				'render_callback' => function() {
					return get_theme_mod( 'footer_copyright' );
				},
			),
		),
	) );

	// Add scroll up enable option
	Kirki::add_field( 'code_manas_config', array(
		'type'        => 'toggle',
		'settings'    => 'scroll_up_enable',
		'label'       => esc_html__( 'Enable scroll up:', 'code-manas' ),
		'description'       => esc_html__( 'This option toggles the "Scroll to top" arrow.', 'code-manas' ),
		'section'     => 'code_manas_footer_section',
		'default'     => 1,
	) );
} );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function code_manas_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function code_manas_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function code_manas_customize_preview_js() {
	wp_enqueue_script( 'code-manas-customizer', get_theme_file_uri( '/assets/js/customizer.js' ), array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'code_manas_customize_preview_js' );

/**
 * Collects all the default theme mods value in an array
 * @return array All the default theme mods values
 */
function code_manas_get_theme_mods_defaults() {
    $defaults = array(
		'featured_title' => esc_html__( 'Readers live longer', 'code-manas' ),
		'featured_content' => esc_html__( 'We\'re more than happy to do this stuff. So please welcome to our theme. Enjoy!', 'code-manas' ),
		'featured_bg' => 'color',
		'featured_bg_color' => '#f5f0ed',
		'featured_enable_on' => 'homepage',

		'blog_excerpt_more' => esc_html__( '...(Continue Reading)', 'code-manas' ),
		'footer_copyright' => __( 'Copyright &#169; All rights reserved', 'code-manas' ),
	);
	return apply_filters( 'code_manas_get_theme_mods_defaults', $defaults );
}

/**
 * Add style for controls which is loaded only on Customizer preview.
 * @return [type] [description]
 */
function code_manas_control_styles() { ?>
	<style>
		.customize-control-kirki-radio-image label {
			margin-right: 10px;
		}
		.customize-control-kirki-radio-image input:checked + label img {
			border: 3px solid #3498DB;
		}
	</style>
	<?php
}
add_action( 'customize_controls_print_styles', 'code_manas_control_styles' );